You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@camel.apache.org by Claus Ibsen <ci...@silverbullet.dk> on 2008/08/12 09:55:17 UTC

RE: svn commit: r685072 - /activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java

Hi

Is it only Vista that has this problem? What about Windows XP? Or others?


Med venlig hilsen
 
Claus Ibsen
......................................
Silverbullet
Skovsgårdsvænget 21
8362 Hørning
Tlf. +45 2962 7576
Web: www.silverbullet.dk
-----Original Message-----
From: ningjiang@apache.org [mailto:ningjiang@apache.org] 
Sent: 12. august 2008 09:30
To: camel-commits@activemq.apache.org
Subject: svn commit: r685072 - /activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java

Author: ningjiang
Date: Tue Aug 12 00:29:45 2008
New Revision: 685072

URL: http://svn.apache.org/viewvc?rev=685072&view=rev
Log:
Try to fix the test error of AMQRouteTest

Modified:
    activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java

Modified: activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java
URL: http://svn.apache.org/viewvc/activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java?rev=685072&r1=685071&r2=685072&view=diff
==============================================================================
--- activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java (original)
+++ activemq/camel/trunk/components/camel-amqp/src/test/java/org/apache/camel/component/amqp/AMQPRouteTest.java Tue Aug 12 00:29:45 2008
@@ -40,8 +40,10 @@
         resultEndpoint.message(0).header("cheese").isEqualTo(123);
 
         sendExchange(expectedBody);
-        // send the message twice to walk around the AMQP's drop first message issue on Windows box
-        sendExchange(expectedBody);
+        if (System.getProperty("os.name").equals("Windows Vista")) {
+            // send the message twice to walk around the AMQP's drop first message issue on Windows Vista box
+            sendExchange(expectedBody);
+        }
 
         resultEndpoint.assertIsSatisfied();